@@ -5,7 +5,7 @@ use locale;
 use Moo;
 extends 'Org::Element';
 
-our $VERSION = '0.25'; # VERSION
+our $VERSION = '0.26'; # VERSION
 
 has level => (is => 'rw');
 has title => (is => 'rw');
@@ -16,6 +16,11 @@ has is_done => (is => 'rw');
 has todo_state => (is => 'rw');
 has progress => (is => 'rw');
 
+sub extra_walkables {
+    my $self = shift;
+    grep {defined} ($self->title);
+}
+
 sub header_as_string {
     my ($self) = @_;
     return $self->_str if defined $self->_str;
@@ -200,7 +205,7 @@ Org::Element::Headline - Represent Org headline
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 DESCRIPTION
 
